# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/session/v1/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.session.v1 import proof_pb2 as sentinel_dot_session_dot_v1_dot_proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/session/v1/msg.proto\x12\x13sentinel.session.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fsentinel/session/v1/proof.proto\"8\n\x0fMsgStartRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0c\n\x04node\x18\x03 \x01(\t\"c\n\x10MsgUpdateRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12/\n\x05proof\x18\x02 \x01(\x0b\x32\x1a.sentinel.session.v1.ProofB\x04\xc8\xde\x1f\x00\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"8\n\rMsgEndRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0e\n\x06rating\x18\x03 \x01(\x04\"\x12\n\x10MsgStartResponse\"\x13\n\x11MsgUpdateResponse\"\x10\n\x0eMsgEndResponse2\x94\x02\n\nMsgService\x12W\n\x08MsgStart\x12$.sentinel.session.v1.MsgStartRequest\x1a%.sentinel.session.v1.MsgStartResponse\x12Z\n\tMsgUpdate\x12%.sentinel.session.v1.MsgUpdateRequest\x1a&.sentinel.session.v1.MsgUpdateResponse\x12Q\n\x06MsgEnd\x12\".sentinel.session.v1.MsgEndRequest\x1a#.sentinel.session.v1.MsgEndResponseB:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v1.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\250\342\036\000\310\341\036\000'
  _MSGUPDATEREQUEST.fields_by_name['proof']._options = None
  _MSGUPDATEREQUEST.fields_by_name['proof']._serialized_options = b'\310\336\037\000'
  _MSGSTARTREQUEST._serialized_start=109
  _MSGSTARTREQUEST._serialized_end=165
  _MSGUPDATEREQUEST._serialized_start=167
  _MSGUPDATEREQUEST._serialized_end=266
  _MSGENDREQUEST._serialized_start=268
  _MSGENDREQUEST._serialized_end=324
  _MSGSTARTRESPONSE._serialized_start=326
  _MSGSTARTRESPONSE._serialized_end=344
  _MSGUPDATERESPONSE._serialized_start=346
  _MSGUPDATERESPONSE._serialized_end=365
  _MSGENDRESPONSE._serialized_start=367
  _MSGENDRESPONSE._serialized_end=383
  _MSGSERVICE._serialized_start=386
  _MSGSERVICE._serialized_end=662
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MsgSwapRequest(_message.Message):
    __slots__ = ["amount", "frm", "receiver", "tx_hash"]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    TX_HASH_FIELD_NUMBER: _ClassVar[int]
    amount: str
    frm: str
    receiver: str
    tx_hash: bytes
    def __init__(self, frm: _Optional[str] = ..., tx_hash: _Optional[bytes] = ..., receiver: _Optional[str] = ..., amount: _Optional[str] = ...) -> None: ...

class MsgSwapResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/node/v1/events.proto\x12\x10sentinel.node.v1\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto\"[\n\rEventRegister\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12%\n\x08provider\x18\x02 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"provider\"\"Y\n\x0b\x45ventUpdate\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12%\n\x08provider\x18\x02 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"provider\"\"s\n\x0e\x45ventSetStatus\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12<\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:\"status\"B7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v1.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _EVENTREGISTER.fields_by_name['address']._options = None
  _EVENTREGISTER.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTREGISTER.fields_by_name['provider']._options = None
  _EVENTREGISTER.fields_by_name['provider']._serialized_options = b'\362\336\037\017yaml:\"provider\"'
  _EVENTUPDATE.fields_by_name['address']._options = None
  _EVENTUPDATE.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTUPDATE.fields_by_name['provider']._options = None
  _EVENTUPDATE.fields_by_name['provider']._serialized_options = b'\362\336\037\017yaml:\"provider\"'
  _EVENTSETSTATUS.fields_by_name['address']._options = None
  _EVENTSETSTATUS.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTSETSTATUS.fields_by_name['status']._options = None
  _EVENTSETSTATUS.fields_by_name['status']._serialized_options = b'\362\336\037\ryaml:\"status\"'
  _EVENTREGISTER._serialized_start=105
  _EVENTREGISTER._serialized_end=196
  _EVENTUPDATE._serialized_start=198
  _EVENTUPDATE._serialized_end=287
  _EVENTSETSTATUS._serialized_start=289
  _EVENTSETSTATUS._serialized_end=404
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%sentinel/subscription/v1/params.proto\x12\x18sentinel.subscription.v1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"H\n\x06Params\x12>\n\x11inactive_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x42?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.params_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _PARAMS.fields_by_name['inactive_duration']._options = None
  _PARAMS.fields_by_name['inactive_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _PARAMS._serialized_start=121
  _PARAMS._serialized_end=193
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/quota.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$sentinel/subscription/v1/quota.proto\x12\x18sentinel.subscription.v1\x1a\x14gogoproto/gogo.proto\"\x9d\x01\n\x05Quota\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x41\n\tallocated\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12@\n\x08\x63onsumed\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x42?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.quota_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _QUOTA.fields_by_name['allocated']._options = None
  _QUOTA.fields_by_name['allocated']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _QUOTA.fields_by_name['consumed']._options = None
  _QUOTA.fields_by_name['consumed']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _QUOTA._serialized_start=89
  _QUOTA._serialized_end=246
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/provider/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/provider/v1/events.proto\x12\x14sentinel.provider.v1\x1a\x14gogoproto/gogo.proto\"4\n\rEventRegister\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\"2\n\x0b\x45ventUpdate\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"B;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v1.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\250\342\036\000\310\341\036\000'
  _EVENTREGISTER.fields_by_name['address']._options = None
  _EVENTREGISTER.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTUPDATE.fields_by_name['address']._options = None
  _EVENTUPDATE.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTREGISTER._serialized_start=81
  _EVENTREGISTER._serialized_end=133
  _EVENTUPDATE._serialized_start=135
  _EVENTUPDATE._serialized_end=185
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Inflation(_message.Message):
    __slots__ = ["max", "min", "rate_change", "timestamp"]
    MAX_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    RATE_CHANGE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    max: str
    min: str
    rate_change: str
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, max: _Optional[str] = ..., min: _Optional[str] = ..., rate_change: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Subscription(_message.Message):
    __slots__ = ["denom", "deposit", "expiry", "free", "id", "node", "owner", "plan", "price", "status", "status_at"]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    FREE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    STATUS_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    denom: str
    deposit: _coin_pb2.Coin
    expiry: _timestamp_pb2.Timestamp
    free: str
    id: int
    node: str
    owner: str
    plan: int
    price: _coin_pb2.Coin
    status: _status_pb2.Status
    status_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[int] = ..., owner: _Optional[str] = ..., node: _Optional[str] = ..., price: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ..., deposit: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ..., plan: _Optional[int] = ..., denom: _Optional[str] = ..., expiry: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., free: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ..., status_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/provider/v1/provider.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#sentinel/provider/v1/provider.proto\x12\x14sentinel.provider.v1\x1a\x14gogoproto/gogo.proto\"a\n\x08Provider\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08identity\x18\x03 \x01(\t\x12\x0f\n\x07website\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\tB;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v1.provider_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\250\342\036\000\310\341\036\000'
  _PROVIDER._serialized_start=83
  _PROVIDER._serialized_end=180
# @@protoc_insertion_point(module_scope)



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.subscription.v1 import quota_pb2 as _quota_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from sentinel.subscription.v1 import subscription_pb2 as _subscription_pb2
from sentinel.subscription.v1 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ["params"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryQuotaRequest(_message.Message):
    __slots__ = ["address", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    def __init__(self, id: _Optional[int] = ..., address: _Optional[str] = ...) -> None: ...

class QueryQuotaResponse(_message.Message):
    __slots__ = ["quota"]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    quota: _quota_pb2.Quota
    def __init__(self, quota: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ...) -> None: ...

class QueryQuotasRequest(_message.Message):
    __slots__ = ["id", "pagination"]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    id: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryQuotasResponse(_message.Message):
    __slots__ = ["pagination", "quotas"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    QUOTAS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    quotas: _containers.RepeatedCompositeFieldContainer[_quota_pb2.Quota]
    def __init__(self, quotas: _Optional[_Iterable[_Union[_quota_pb2.Quota, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySubscriptionRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QuerySubscriptionResponse(_message.Message):
    __slots__ = ["subscription"]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    subscription: _subscription_pb2.Subscription
    def __init__(self, subscription: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ...) -> None: ...

class QuerySubscriptionsForAddressRequest(_message.Message):
    __slots__ = ["address", "pagination", "status"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    status: _status_pb2.Status
    def __init__(self, address: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySubscriptionsForAddressResponse(_message.Message):
    __slots__ = ["pagination", "subscriptions"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    subscriptions: _containers.RepeatedCompositeFieldContainer[_subscription_pb2.Subscription]
    def __init__(self, subscriptions: _Optional[_Iterable[_Union[_subscription_pb2.Subscription, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySubscriptionsRequest(_message.Message):
    __slots__ = ["pagination"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySubscriptionsResponse(_message.Message):
    __slots__ = ["pagination", "subscriptions"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    subscriptions: _containers.RepeatedCompositeFieldContainer[_subscription_pb2.Subscription]
    def __init__(self, subscriptions: _Optional[_Iterable[_Union[_subscription_pb2.Subscription, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/client/v1/client.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.upgrade.v1beta1 import upgrade_pb2 as cosmos_dot_upgrade_dot_v1beta1_dot_upgrade__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/client/v1/client.proto\x12\x12ibc.core.client.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a$cosmos/upgrade/v1beta1/upgrade.proto\"\x85\x01\n\x15IdentifiedClientState\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x43\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\"\"\x97\x01\n\x18\x43onsensusStateWithHeight\x12\x30\n\x06height\x18\x01 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12I\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\"\"\xa9\x01\n\x15\x43lientConsensusStates\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12g\n\x10\x63onsensus_states\x18\x02 \x03(\x0b\x32,.ibc.core.client.v1.ConsensusStateWithHeightB\x1f\xf2\xde\x1f\x17yaml:\"consensus_states\"\xc8\xde\x1f\x00\"\xb8\x01\n\x14\x43lientUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x37\n\x11subject_client_id\x18\x03 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"subject_client_id\"\x12=\n\x14substitute_client_id\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:\"substitute_client_id\":\x04\x88\xa0\x1f\x00\"\xcc\x01\n\x0fUpgradeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x30\n\x04plan\x18\x03 \x01(\x0b\x32\x1c.cosmos.upgrade.v1beta1.PlanB\x04\xc8\xde\x1f\x00\x12U\n\x15upgraded_client_state\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyB \xf2\xde\x1f\x1cyaml:\"upgraded_client_state\":\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x01\"|\n\x06Height\x12\x33\n\x0frevision_number\x18\x01 \x01(\x04\x42\x1a\xf2\xde\x1f\x16yaml:\"revision_number\"\x12\x33\n\x0frevision_height\x18\x02 \x01(\x04\x42\x1a\xf2\xde\x1f\x16yaml:\"revision_height\":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"=\n\x06Params\x12\x33\n\x0f\x61llowed_clients\x18\x01 \x03(\tB\x1a\xf2\xde\x1f\x16yaml:\"allowed_clients\"B:Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.client_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/types'
  _IDENTIFIEDCLIENTSTATE.fields_by_name['client_id']._options = None
  _IDENTIFIEDCLIENTSTATE.fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _IDENTIFIEDCLIENTSTATE.fields_by_name['client_state']._options = None
  _IDENTIFIEDCLIENTSTATE.fields_by_name['client_state']._serialized_options = b'\362\336\037\023yaml:\"client_state\"'
  _CONSENSUSSTATEWITHHEIGHT.fields_by_name['height']._options = None
  _CONSENSUSSTATEWITHHEIGHT.fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _CONSENSUSSTATEWITHHEIGHT.fields_by_name['consensus_state']._options = None
  _CONSENSUSSTATEWITHHEIGHT.fields_by_name['consensus_state']._serialized_options = b'\362\336\037\026yaml:\"consensus_state\"'
  _CLIENTCONSENSUSSTATES.fields_by_name['client_id']._options = None
  _CLIENTCONSENSUSSTATES.fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _CLIENTCONSENSUSSTATES.fields_by_name['consensus_states']._options = None
  _CLIENTCONSENSUSSTATES.fields_by_name['consensus_states']._serialized_options = b'\362\336\037\027yaml:\"consensus_states\"\310\336\037\000'
  _CLIENTUPDATEPROPOSAL.fields_by_name['subject_client_id']._options = None
  _CLIENTUPDATEPROPOSAL.fields_by_name['subject_client_id']._serialized_options = b'\362\336\037\030yaml:\"subject_client_id\"'
  _CLIENTUPDATEPROPOSAL.fields_by_name['substitute_client_id']._options = None
  _CLIENTUPDATEPROPOSAL.fields_by_name['substitute_client_id']._serialized_options = b'\362\336\037\033yaml:\"substitute_client_id\"'
  _CLIENTUPDATEPROPOSAL._options = None
  _CLIENTUPDATEPROPOSAL._serialized_options = b'\210\240\037\000'
  _UPGRADEPROPOSAL.fields_by_name['plan']._options = None
  _UPGRADEPROPOSAL.fields_by_name['plan']._serialized_options = b'\310\336\037\000'
  _UPGRADEPROPOSAL.fields_by_name['upgraded_client_state']._options = None
  _UPGRADEPROPOSAL.fields_by_name['upgraded_client_state']._serialized_options = b'\362\336\037\034yaml:\"upgraded_client_state\"'
  _UPGRADEPROPOSAL._options = None
  _UPGRADEPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\001'
  _HEIGHT.fields_by_name['revision_number']._options = None
  _HEIGHT.fields_by_name['revision_number']._serialized_options = b'\362\336\037\026yaml:\"revision_number\"'
  _HEIGHT.fields_by_name['revision_height']._options = None
  _HEIGHT.fields_by_name['revision_height']._serialized_options = b'\362\336\037\026yaml:\"revision_height\"'
  _HEIGHT._options = None
  _HEIGHT._serialized_options = b'\210\240\037\000\230\240\037\000'
  _PARAMS.fields_by_name['allowed_clients']._options = None
  _PARAMS.fields_by_name['allowed_clients']._serialized_options = b'\362\336\037\026yaml:\"allowed_clients\"'
  _IDENTIFIEDCLIENTSTATE._serialized_start=143
  _IDENTIFIEDCLIENTSTATE._serialized_end=276
  _CONSENSUSSTATEWITHHEIGHT._serialized_start=279
  _CONSENSUSSTATEWITHHEIGHT._serialized_end=430
  _CLIENTCONSENSUSSTATES._serialized_start=433
  _CLIENTCONSENSUSSTATES._serialized_end=602
  _CLIENTUPDATEPROPOSAL._serialized_start=605
  _CLIENTUPDATEPROPOSAL._serialized_end=789
  _UPGRADEPROPOSAL._serialized_start=792
  _UPGRADEPROPOSAL._serialized_end=996
  _HEIGHT._serialized_start=998
  _HEIGHT._serialized_end=1122
  _PARAMS._serialized_start=1124
  _PARAMS._serialized_end=1185
# @@protoc_insertion_point(module_scope)



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.swap.v1 import swap_pb2 as _swap_pb2
from sentinel.swap.v1 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ["params"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QuerySwapRequest(_message.Message):
    __slots__ = ["tx_hash"]
    TX_HASH_FIELD_NUMBER: _ClassVar[int]
    tx_hash: bytes
    def __init__(self, tx_hash: _Optional[bytes] = ...) -> None: ...

class QuerySwapResponse(_message.Message):
    __slots__ = ["swap"]
    SWAP_FIELD_NUMBER: _ClassVar[int]
    swap: _swap_pb2.Swap
    def __init__(self, swap: _Optional[_Union[_swap_pb2.Swap, _Mapping]] = ...) -> None: ...

class QuerySwapsRequest(_message.Message):
    __slots__ = ["pagination"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySwapsResponse(_message.Message):
    __slots__ = ["pagination", "swaps"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SWAPS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    swaps: _containers.RepeatedCompositeFieldContainer[_swap_pb2.Swap]
    def __init__(self, swaps: _Optional[_Iterable[_Union[_swap_pb2.Swap, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/mint/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.mint.v1 import inflation_pb2 as sentinel_dot_mint_dot_v1_dot_inflation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/mint/v1/genesis.proto\x12\x10sentinel.mint.v1\x1a\x14gogoproto/gogo.proto\x1a sentinel/mint/v1/inflation.proto\"Z\n\x0cGenesisState\x12J\n\ninflations\x18\x01 \x03(\x0b\x32\x1b.sentinel.mint.v1.InflationB\x19\xf2\xde\x1f\x11yaml:\"inflations\"\xc8\xde\x1f\x00\x42\x37Z-github.com/sentinel-official/hub/x/mint/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.mint.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/mint/types\250\342\036\000\310\341\036\000'
  _GENESISSTATE.fields_by_name['inflations']._options = None
  _GENESISSTATE.fields_by_name['inflations']._serialized_options = b'\362\336\037\021yaml:\"inflations\"\310\336\037\000'
  _GENESISSTATE._serialized_start=108
  _GENESISSTATE._serialized_end=198
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/vpn/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.deposit.v1 import deposit_pb2 as sentinel_dot_deposit_dot_v1_dot_deposit__pb2
from sentinel.node.v1 import genesis_pb2 as sentinel_dot_node_dot_v1_dot_genesis__pb2
from sentinel.plan.v1 import genesis_pb2 as sentinel_dot_plan_dot_v1_dot_genesis__pb2
from sentinel.provider.v1 import genesis_pb2 as sentinel_dot_provider_dot_v1_dot_genesis__pb2
from sentinel.session.v1 import genesis_pb2 as sentinel_dot_session_dot_v1_dot_genesis__pb2
from sentinel.subscription.v1 import genesis_pb2 as sentinel_dot_subscription_dot_v1_dot_genesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/vpn/v1/genesis.proto\x12\x0fsentinel.vpn.v1\x1a\x14gogoproto/gogo.proto\x1a!sentinel/deposit/v1/deposit.proto\x1a\x1esentinel/node/v1/genesis.proto\x1a\x1esentinel/plan/v1/genesis.proto\x1a\"sentinel/provider/v1/genesis.proto\x1a!sentinel/session/v1/genesis.proto\x1a&sentinel/subscription/v1/genesis.proto\"\xd2\x02\n\x0cGenesisState\x12\x34\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32\x1c.sentinel.deposit.v1.DepositB\x04\xc8\xde\x1f\x00\x12-\n\x05nodes\x18\x02 \x01(\x0b\x32\x1e.sentinel.node.v1.GenesisState\x12\x32\n\x05plans\x18\x03 \x03(\x0b\x32\x1d.sentinel.plan.v1.GenesisPlanB\x04\xc8\xde\x1f\x00\x12\x35\n\tproviders\x18\x04 \x01(\x0b\x32\".sentinel.provider.v1.GenesisState\x12\x33\n\x08sessions\x18\x05 \x01(\x0b\x32!.sentinel.session.v1.GenesisState\x12=\n\rsubscriptions\x18\x06 \x01(\x0b\x32&.sentinel.subscription.v1.GenesisStateB6Z,github.com/sentinel-official/hub/x/vpn/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.vpn.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/sentinel-official/hub/x/vpn/types\250\342\036\000\310\341\036\000'
  _GENESISSTATE.fields_by_name['deposits']._options = None
  _GENESISSTATE.fields_by_name['deposits']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['plans']._options = None
  _GENESISSTATE.fields_by_name['plans']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=283
  _GENESISSTATE._serialized_end=621
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.provider.v1 import params_pb2 as _params_pb2
from sentinel.provider.v1 import provider_pb2 as _provider_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ["params", "providers"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    providers: _containers.RepeatedCompositeFieldContainer[_provider_pb2.Provider]
    def __init__(self, providers: _Optional[_Iterable[_Union[_provider_pb2.Provider, _Mapping]]] = ..., params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.provider.v1 import provider_pb2 as _provider_pb2
from sentinel.provider.v1 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ["params"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryProviderRequest(_message.Message):
    __slots__ = ["address"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class QueryProviderResponse(_message.Message):
    __slots__ = ["provider"]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    provider: _provider_pb2.Provider
    def __init__(self, provider: _Optional[_Union[_provider_pb2.Provider, _Mapping]] = ...) -> None: ...

class QueryProvidersRequest(_message.Message):
    __slots__ = ["pagination"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryProvidersResponse(_message.Message):
    __slots__ = ["pagination", "providers"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    providers: _containers.RepeatedCompositeFieldContainer[_provider_pb2.Provider]
    def __init__(self, providers: _Optional[_Iterable[_Union[_provider_pb2.Provider, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.deposit.v1 import deposit_pb2 as _deposit_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryDepositRequest(_message.Message):
    __slots__ = ["address"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class QueryDepositResponse(_message.Message):
    __slots__ = ["deposit"]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    deposit: _deposit_pb2.Deposit
    def __init__(self, deposit: _Optional[_Union[_deposit_pb2.Deposit, _Mapping]] = ...) -> None: ...

class QueryDepositsRequest(_message.Message):
    __slots__ = ["pagination"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryDepositsResponse(_message.Message):
    __slots__ = ["deposits", "pagination"]
    DEPOSITS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    deposits: _containers.RepeatedCompositeFieldContainer[_deposit_pb2.Deposit]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, deposits: _Optional[_Iterable[_Union[_deposit_pb2.Deposit, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/deposit/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n sentinel/deposit/v1/events.proto\x12\x13sentinel.deposit.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\"\x9b\x01\n\x08\x45ventAdd\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12j\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB@\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x0cyaml:\"coins\"\"\xa0\x01\n\rEventSubtract\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12j\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB@\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x0cyaml:\"coins\"B:Z0github.com/sentinel-official/hub/x/deposit/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.deposit.v1.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/deposit/types\250\342\036\000\310\341\036\000'
  _EVENTADD.fields_by_name['address']._options = None
  _EVENTADD.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTADD.fields_by_name['coins']._options = None
  _EVENTADD.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\014yaml:\"coins\"'
  _EVENTSUBTRACT.fields_by_name['address']._options = None
  _EVENTSUBTRACT.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTSUBTRACT.fields_by_name['coins']._options = None
  _EVENTSUBTRACT.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\014yaml:\"coins\"'
  _EVENTADD._serialized_start=112
  _EVENTADD._serialized_end=267
  _EVENTSUBTRACT._serialized_start=270
  _EVENTSUBTRACT._serialized_end=430
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

BENCHGEN_ALL_FIELD_NUMBER: _ClassVar[int]
BENCHGEN_FIELD_NUMBER: _ClassVar[int]
CASTKEY_FIELD_NUMBER: _ClassVar[int]
CASTREPEATED_FIELD_NUMBER: _ClassVar[int]
CASTTYPE_FIELD_NUMBER: _ClassVar[int]
CASTVALUE_FIELD_NUMBER: _ClassVar[int]
COMPARE_ALL_FIELD_NUMBER: _ClassVar[int]
COMPARE_FIELD_NUMBER: _ClassVar[int]
CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
CUSTOMTYPE_FIELD_NUMBER: _ClassVar[int]
DESCRIPTION_ALL_FIELD_NUMBER: _ClassVar[int]
DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
DESCRIPTOR: _descriptor.FileDescriptor
EMBED_FIELD_NUMBER: _ClassVar[int]
ENUMDECL_ALL_FIELD_NUMBER: _ClassVar[int]
ENUMDECL_FIELD_NUMBER: _ClassVar[int]
ENUMVALUE_CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
ENUM_CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
ENUM_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
ENUM_STRINGER_FIELD_NUMBER: _ClassVar[int]
EQUAL_ALL_FIELD_NUMBER: _ClassVar[int]
EQUAL_FIELD_NUMBER: _ClassVar[int]
FACE_ALL_FIELD_NUMBER: _ClassVar[int]
FACE_FIELD_NUMBER: _ClassVar[int]
GOGOPROTO_IMPORT_FIELD_NUMBER: _ClassVar[int]
GOPROTO_ENUM_PREFIX_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_ENUM_PREFIX_FIELD_NUMBER: _ClassVar[int]
GOPROTO_ENUM_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_ENUM_STRINGER_FIELD_NUMBER: _ClassVar[int]
GOPROTO_EXTENSIONS_MAP_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_EXTENSIONS_MAP_FIELD_NUMBER: _ClassVar[int]
GOPROTO_GETTERS_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_GETTERS_FIELD_NUMBER: _ClassVar[int]
GOPROTO_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
GOPROTO_SIZECACHE_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_SIZECACHE_FIELD_NUMBER: _ClassVar[int]
GOPROTO_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_STRINGER_FIELD_NUMBER: _ClassVar[int]
GOPROTO_UNKEYED_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_UNKEYED_FIELD_NUMBER: _ClassVar[int]
GOPROTO_UNRECOGNIZED_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_UNRECOGNIZED_FIELD_NUMBER: _ClassVar[int]
GOSTRING_ALL_FIELD_NUMBER: _ClassVar[int]
GOSTRING_FIELD_NUMBER: _ClassVar[int]
JSONTAG_FIELD_NUMBER: _ClassVar[int]
MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
MARSHALER_FIELD_NUMBER: _ClassVar[int]
MESSAGENAME_ALL_FIELD_NUMBER: _ClassVar[int]
MESSAGENAME_FIELD_NUMBER: _ClassVar[int]
MORETAGS_FIELD_NUMBER: _ClassVar[int]
NULLABLE_FIELD_NUMBER: _ClassVar[int]
ONLYONE_ALL_FIELD_NUMBER: _ClassVar[int]
ONLYONE_FIELD_NUMBER: _ClassVar[int]
POPULATE_ALL_FIELD_NUMBER: _ClassVar[int]
POPULATE_FIELD_NUMBER: _ClassVar[int]
PROTOSIZER_ALL_FIELD_NUMBER: _ClassVar[int]
PROTOSIZER_FIELD_NUMBER: _ClassVar[int]
SIZER_ALL_FIELD_NUMBER: _ClassVar[int]
SIZER_FIELD_NUMBER: _ClassVar[int]
STABLE_MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
STABLE_MARSHALER_FIELD_NUMBER: _ClassVar[int]
STDDURATION_FIELD_NUMBER: _ClassVar[int]
STDTIME_FIELD_NUMBER: _ClassVar[int]
STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
STRINGER_FIELD_NUMBER: _ClassVar[int]
TESTGEN_ALL_FIELD_NUMBER: _ClassVar[int]
TESTGEN_FIELD_NUMBER: _ClassVar[int]
TYPEDECL_ALL_FIELD_NUMBER: _ClassVar[int]
TYPEDECL_FIELD_NUMBER: _ClassVar[int]
UNMARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
UNMARSHALER_FIELD_NUMBER: _ClassVar[int]
UNSAFE_MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
UNSAFE_MARSHALER_FIELD_NUMBER: _ClassVar[int]
UNSAFE_UNMARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
UNSAFE_UNMARSHALER_FIELD_NUMBER: _ClassVar[int]
VERBOSE_EQUAL_ALL_FIELD_NUMBER: _ClassVar[int]
VERBOSE_EQUAL_FIELD_NUMBER: _ClassVar[int]
WKTPOINTER_FIELD_NUMBER: _ClassVar[int]
benchgen: _descriptor.FieldDescriptor
benchgen_all: _descriptor.FieldDescriptor
castkey: _descriptor.FieldDescriptor
castrepeated: _descriptor.FieldDescriptor
casttype: _descriptor.FieldDescriptor
castvalue: _descriptor.FieldDescriptor
compare: _descriptor.FieldDescriptor
compare_all: _descriptor.FieldDescriptor
customname: _descriptor.FieldDescriptor
customtype: _descriptor.FieldDescriptor
description: _descriptor.FieldDescriptor
description_all: _descriptor.FieldDescriptor
embed: _descriptor.FieldDescriptor
enum_customname: _descriptor.FieldDescriptor
enum_stringer: _descriptor.FieldDescriptor
enum_stringer_all: _descriptor.FieldDescriptor
enumdecl: _descriptor.FieldDescriptor
enumdecl_all: _descriptor.FieldDescriptor
enumvalue_customname: _descriptor.FieldDescriptor
equal: _descriptor.FieldDescriptor
equal_all: _descriptor.FieldDescriptor
face: _descriptor.FieldDescriptor
face_all: _descriptor.FieldDescriptor
gogoproto_import: _descriptor.FieldDescriptor
goproto_enum_prefix: _descriptor.FieldDescriptor
goproto_enum_prefix_all: _descriptor.FieldDescriptor
goproto_enum_stringer: _descriptor.FieldDescriptor
goproto_enum_stringer_all: _descriptor.FieldDescriptor
goproto_extensions_map: _descriptor.FieldDescriptor
goproto_extensions_map_all: _descriptor.FieldDescriptor
goproto_getters: _descriptor.FieldDescriptor
goproto_getters_all: _descriptor.FieldDescriptor
goproto_registration: _descriptor.FieldDescriptor
goproto_sizecache: _descriptor.FieldDescriptor
goproto_sizecache_all: _descriptor.FieldDescriptor
goproto_stringer: _descriptor.FieldDescriptor
goproto_stringer_all: _descriptor.FieldDescriptor
goproto_unkeyed: _descriptor.FieldDescriptor
goproto_unkeyed_all: _descriptor.FieldDescriptor
goproto_unrecognized: _descriptor.FieldDescriptor
goproto_unrecognized_all: _descriptor.FieldDescriptor
gostring: _descriptor.FieldDescriptor
gostring_all: _descriptor.FieldDescriptor
jsontag: _descriptor.FieldDescriptor
marshaler: _descriptor.FieldDescriptor
marshaler_all: _descriptor.FieldDescriptor
messagename: _descriptor.FieldDescriptor
messagename_all: _descriptor.FieldDescriptor
moretags: _descriptor.FieldDescriptor
nullable: _descriptor.FieldDescriptor
onlyone: _descriptor.FieldDescriptor
onlyone_all: _descriptor.FieldDescriptor
populate: _descriptor.FieldDescriptor
populate_all: _descriptor.FieldDescriptor
protosizer: _descriptor.FieldDescriptor
protosizer_all: _descriptor.FieldDescriptor
sizer: _descriptor.FieldDescriptor
sizer_all: _descriptor.FieldDescriptor
stable_marshaler: _descriptor.FieldDescriptor
stable_marshaler_all: _descriptor.FieldDescriptor
stdduration: _descriptor.FieldDescriptor
stdtime: _descriptor.FieldDescriptor
stringer: _descriptor.FieldDescriptor
stringer_all: _descriptor.FieldDescriptor
testgen: _descriptor.FieldDescriptor
testgen_all: _descriptor.FieldDescriptor
typedecl: _descriptor.FieldDescriptor
typedecl_all: _descriptor.FieldDescriptor
unmarshaler: _descriptor.FieldDescriptor
unmarshaler_all: _descriptor.FieldDescriptor
unsafe_marshaler: _descriptor.FieldDescriptor
unsafe_marshaler_all: _descriptor.FieldDescriptor
unsafe_unmarshaler: _descriptor.FieldDescriptor
unsafe_unmarshaler_all: _descriptor.FieldDescriptor
verbose_equal: _descriptor.FieldDescriptor
verbose_equal_all: _descriptor.FieldDescriptor
wktpointer: _descriptor.FieldDescriptor



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from sentinel.types.v1 import bandwidth_pb2 as _bandwidth_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Proof(_message.Message):
    __slots__ = ["bandwidth", "duration", "id"]
    BANDWIDTH_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    bandwidth: _bandwidth_pb2.Bandwidth
    duration: _duration_pb2.Duration
    id: int
    def __init__(self, id: _Optional[int] = ..., duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., bandwidth: _Optional[_Union[_bandwidth_pb2.Bandwidth, _Mapping]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.session.v1 import proof_pb2 as _proof_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgEndRequest(_message.Message):
    __slots__ = ["frm", "id", "rating"]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    frm: str
    id: int
    rating: int
    def __init__(self, frm: _Optional[str] = ..., id: _Optional[int] = ..., rating: _Optional[int] = ...) -> None: ...

class MsgEndResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgStartRequest(_message.Message):
    __slots__ = ["frm", "id", "node"]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    frm: str
    id: int
    node: str
    def __init__(self, frm: _Optional[str] = ..., id: _Optional[int] = ..., node: _Optional[str] = ...) -> None: ...

class MsgStartResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgUpdateRequest(_message.Message):
    __slots__ = ["frm", "proof", "signature"]
    FRM_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    frm: str
    proof: _proof_pb2.Proof
    signature: bytes
    def __init__(self, frm: _Optional[str] = ..., proof: _Optional[_Union[_proof_pb2.Proof, _Mapping]] = ..., signature: _Optional[bytes] = ...) -> None: ...

class MsgUpdateResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v1/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asentinel/node/v1/msg.proto\x12\x10sentinel.node.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1esentinel/types/v1/status.proto\"\xb2\x01\n\x12MsgRegisterRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12Z\n\x05price\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12!\n\nremote_url\x18\x04 \x01(\tB\r\xe2\xde\x1f\tRemoteURL\"\xb0\x01\n\x10MsgUpdateRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12Z\n\x05price\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12!\n\nremote_url\x18\x04 \x01(\tB\r\xe2\xde\x1f\tRemoteURL\"M\n\x13MsgSetStatusRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\"\x15\n\x13MsgRegisterResponse\"\x13\n\x11MsgUpdateResponse\"\x16\n\x14MsgSetStatusResponse2\x9d\x02\n\nMsgService\x12Z\n\x0bMsgRegister\x12$.sentinel.node.v1.MsgRegisterRequest\x1a%.sentinel.node.v1.MsgRegisterResponse\x12T\n\tMsgUpdate\x12\".sentinel.node.v1.MsgUpdateRequest\x1a#.sentinel.node.v1.MsgUpdateResponse\x12]\n\x0cMsgSetStatus\x12%.sentinel.node.v1.MsgSetStatusRequest\x1a&.sentinel.node.v1.MsgSetStatusResponseB7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v1.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _MSGREGISTERREQUEST.fields_by_name['price']._options = None
  _MSGREGISTERREQUEST.fields_by_name['price']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGREGISTERREQUEST.fields_by_name['remote_url']._options = None
  _MSGREGISTERREQUEST.fields_by_name['remote_url']._serialized_options = b'\342\336\037\tRemoteURL'
  _MSGUPDATEREQUEST.fields_by_name['price']._options = None
  _MSGUPDATEREQUEST.fields_by_name['price']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGUPDATEREQUEST.fields_by_name['remote_url']._options = None
  _MSGUPDATEREQUEST.fields_by_name['remote_url']._serialized_options = b'\342\336\037\tRemoteURL'
  _MSGREGISTERREQUEST._serialized_start=135
  _MSGREGISTERREQUEST._serialized_end=313
  _MSGUPDATEREQUEST._serialized_start=316
  _MSGUPDATEREQUEST._serialized_end=492
  _MSGSETSTATUSREQUEST._serialized_start=494
  _MSGSETSTATUSREQUEST._serialized_end=571
  _MSGREGISTERRESPONSE._serialized_start=573
  _MSGREGISTERRESPONSE._serialized_end=594
  _MSGUPDATERESPONSE._serialized_start=596
  _MSGUPDATERESPONSE._serialized_end=615
  _MSGSETSTATUSRESPONSE._serialized_start=617
  _MSGSETSTATUSRESPONSE._serialized_end=639
  _MSGSERVICE._serialized_start=642
  _MSGSERVICE._serialized_end=927
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/deposit/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.deposit.v1 import deposit_pb2 as sentinel_dot_deposit_dot_v1_dot_deposit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/deposit/v1/querier.proto\x12\x13sentinel.deposit.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a!sentinel/deposit/v1/deposit.proto\"R\n\x14QueryDepositsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"&\n\x13QueryDepositRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x8a\x01\n\x15QueryDepositsResponse\x12\x34\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32\x1c.sentinel.deposit.v1.DepositB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"K\n\x14QueryDepositResponse\x12\x33\n\x07\x64\x65posit\x18\x01 \x01(\x0b\x32\x1c.sentinel.deposit.v1.DepositB\x04\xc8\xde\x1f\x00\x32\xa8\x02\n\x0cQueryService\x12\x82\x01\n\rQueryDeposits\x12).sentinel.deposit.v1.QueryDepositsRequest\x1a*.sentinel.deposit.v1.QueryDepositsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/sentinel/deposits\x12\x92\x01\n\x0cQueryDeposit\x12(.sentinel.deposit.v1.QueryDepositRequest\x1a).sentinel.deposit.v1.QueryDepositResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/sentinel/accounts/{address}/depositsB:Z0github.com/sentinel-official/hub/x/deposit/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.deposit.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/deposit/types\250\342\036\000\310\341\036\000'
  _QUERYDEPOSITSRESPONSE.fields_by_name['deposits']._options = None
  _QUERYDEPOSITSRESPONSE.fields_by_name['deposits']._serialized_options = b'\310\336\037\000'
  _QUERYDEPOSITRESPONSE.fields_by_name['deposit']._options = None
  _QUERYDEPOSITRESPONSE.fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QueryDeposits']._options = None
  _QUERYSERVICE.methods_by_name['QueryDeposits']._serialized_options = b'\202\323\344\223\002\024\022\022/sentinel/deposits'
  _QUERYSERVICE.methods_by_name['QueryDeposit']._options = None
  _QUERYSERVICE.methods_by_name['QueryDeposit']._serialized_options = b'\202\323\344\223\002\'\022%/sentinel/accounts/{address}/deposits'
  _QUERYDEPOSITSREQUEST._serialized_start=189
  _QUERYDEPOSITSREQUEST._serialized_end=271
  _QUERYDEPOSITREQUEST._serialized_start=273
  _QUERYDEPOSITREQUEST._serialized_end=311
  _QUERYDEPOSITSRESPONSE._serialized_start=314
  _QUERYDEPOSITSRESPONSE._serialized_end=452
  _QUERYDEPOSITRESPONSE._serialized_start=454
  _QUERYDEPOSITRESPONSE._serialized_end=529
  _QUERYSERVICE._serialized_start=532
  _QUERYSERVICE._serialized_end=828
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Bandwidth(_message.Message):
    __slots__ = ["download", "upload"]
    DOWNLOAD_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_FIELD_NUMBER: _ClassVar[int]
    download: str
    upload: str
    def __init__(self, upload: _Optional[str] = ..., download: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/deposit/v1/deposit.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/deposit/v1/deposit.proto\x12\x13sentinel.deposit.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"v\n\x07\x44\x65posit\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12Z\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsB:Z0github.com/sentinel-official/hub/x/deposit/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.deposit.v1.deposit_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/deposit/types\250\342\036\000\310\341\036\000'
  _DEPOSIT.fields_by_name['coins']._options = None
  _DEPOSIT.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _DEPOSIT._serialized_start=112
  _DEPOSIT._serialized_end=230
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
STATUS_ACTIVE: Status
STATUS_INACTIVE: Status
STATUS_INACTIVE_PENDING: Status
STATUS_UNSPECIFIED: Status

class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/types/v1/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/types/v1/status.proto\x12\x11sentinel.types.v1\x1a\x14gogoproto/gogo.proto*\xa5\x01\n\x06Status\x12\'\n\x12STATUS_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUnspecified\x12\x1d\n\rSTATUS_ACTIVE\x10\x01\x1a\n\x8a\x9d \x06\x41\x63tive\x12\x30\n\x17STATUS_INACTIVE_PENDING\x10\x02\x1a\x13\x8a\x9d \x0fInactivePending\x12!\n\x0fSTATUS_INACTIVE\x10\x03\x1a\x0c\x8a\x9d \x08InactiveB0Z&github.com/sentinel-official/hub/types\xc8\xe1\x1e\x00\xd0\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.types.v1.status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/sentinel-official/hub/types\310\341\036\000\320\341\036\000'
  _STATUS.values_by_name["STATUS_UNSPECIFIED"]._options = None
  _STATUS.values_by_name["STATUS_UNSPECIFIED"]._serialized_options = b'\212\235 \013Unspecified'
  _STATUS.values_by_name["STATUS_ACTIVE"]._options = None
  _STATUS.values_by_name["STATUS_ACTIVE"]._serialized_options = b'\212\235 \006Active'
  _STATUS.values_by_name["STATUS_INACTIVE_PENDING"]._options = None
  _STATUS.values_by_name["STATUS_INACTIVE_PENDING"]._serialized_options = b'\212\235 \017InactivePending'
  _STATUS.values_by_name["STATUS_INACTIVE"]._options = None
  _STATUS.values_by_name["STATUS_INACTIVE"]._serialized_options = b'\212\235 \010Inactive'
  _STATUS._serialized_start=76
  _STATUS._serialized_end=241
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from sentinel.types.v1 import bandwidth_pb2 as _bandwidth_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Session(_message.Message):
    __slots__ = ["address", "bandwidth", "duration", "id", "node", "status", "status_at", "subscription"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BANDWIDTH_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    STATUS_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    address: str
    bandwidth: _bandwidth_pb2.Bandwidth
    duration: _duration_pb2.Duration
    id: int
    node: str
    status: _status_pb2.Status
    status_at: _timestamp_pb2.Timestamp
    subscription: int
    def __init__(self, id: _Optional[int] = ..., subscription: _Optional[int] = ..., node: _Optional[str] = ..., address: _Optional[str] = ..., duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., bandwidth: _Optional[_Union[_bandwidth_pb2.Bandwidth, _Mapping]] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ..., status_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/feegrant/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.feegrant.v1beta1 import feegrant_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_feegrant__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/feegrant/v1beta1/query.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a&cosmos/feegrant/v1beta1/feegrant.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\"9\n\x15QueryAllowanceRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\"K\n\x16QueryAllowanceResponse\x12\x31\n\tallowance\x18\x01 \x01(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\"e\n\x16QueryAllowancesRequest\x12\x0f\n\x07grantee\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8a\x01\n\x17QueryAllowancesResponse\x12\x32\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xdf\x02\n\x05Query\x12\xac\x01\n\tAllowance\x12..cosmos.feegrant.v1beta1.QueryAllowanceRequest\x1a/.cosmos.feegrant.v1beta1.QueryAllowanceResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/cosmos/feegrant/v1beta1/allowance/{granter}/{grantee}\x12\xa6\x01\n\nAllowances\x12/.cosmos.feegrant.v1beta1.QueryAllowancesRequest\x1a\x30.cosmos.feegrant.v1beta1.QueryAllowancesResponse\"5\x82\xd3\xe4\x93\x02/\x12-/cosmos/feegrant/v1beta1/allowances/{grantee}B)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/cosmos/cosmos-sdk/x/feegrant'
  _QUERY.methods_by_name['Allowance']._options = None
  _QUERY.methods_by_name['Allowance']._serialized_options = b'\202\323\344\223\0028\0226/cosmos/feegrant/v1beta1/allowance/{granter}/{grantee}'
  _QUERY.methods_by_name['Allowances']._options = None
  _QUERY.methods_by_name['Allowances']._serialized_options = b'\202\323\344\223\002/\022-/cosmos/feegrant/v1beta1/allowances/{grantee}'
  _QUERYALLOWANCEREQUEST._serialized_start=178
  _QUERYALLOWANCEREQUEST._serialized_end=235
  _QUERYALLOWANCERESPONSE._serialized_start=237
  _QUERYALLOWANCERESPONSE._serialized_end=312
  _QUERYALLOWANCESREQUEST._serialized_start=314
  _QUERYALLOWANCESREQUEST._serialized_end=415
  _QUERYALLOWANCESRESPONSE._serialized_start=418
  _QUERYALLOWANCESRESPONSE._serialized_end=556
  _QUERY._serialized_start=559
  _QUERY._serialized_end=910
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/mint/v1/inflation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n sentinel/mint/v1/inflation.proto\x12\x10sentinel.mint.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc9\x02\n\tInflation\x12I\n\x03max\x18\x01 \x01(\tB<\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\nyaml:\"max\"\xc8\xde\x1f\x00\x12I\n\x03min\x18\x02 \x01(\tB<\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\nyaml:\"min\"\xc8\xde\x1f\x00\x12Y\n\x0brate_change\x18\x03 \x01(\tBD\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x12yaml:\"rate_change\"\xc8\xde\x1f\x00\x12K\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\xf2\xde\x1f\x10yaml:\"timestamp\"\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x42\x37Z-github.com/sentinel-official/hub/x/mint/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.mint.v1.inflation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/mint/types\250\342\036\000\310\341\036\000'
  _INFLATION.fields_by_name['max']._options = None
  _INFLATION.fields_by_name['max']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\nyaml:\"max\"\310\336\037\000'
  _INFLATION.fields_by_name['min']._options = None
  _INFLATION.fields_by_name['min']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\nyaml:\"min\"\310\336\037\000'
  _INFLATION.fields_by_name['rate_change']._options = None
  _INFLATION.fields_by_name['rate_change']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\022yaml:\"rate_change\"\310\336\037\000'
  _INFLATION.fields_by_name['timestamp']._options = None
  _INFLATION.fields_by_name['timestamp']._serialized_options = b'\362\336\037\020yaml:\"timestamp\"\310\336\037\000\220\337\037\001'
  _INFLATION._serialized_start=110
  _INFLATION._serialized_end=439
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from sentinel.node.v1 import node_pb2 as sentinel_dot_node_dot_v1_dot_node__pb2
from sentinel.node.v1 import params_pb2 as sentinel_dot_node_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/node/v1/querier.proto\x12\x10sentinel.node.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1esentinel/types/v1/status.proto\x1a\x1bsentinel/node/v1/node.proto\x1a\x1dsentinel/node/v1/params.proto\"z\n\x11QueryNodesRequest\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x96\x01\n\x1cQueryNodesForProviderRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"#\n\x10QueryNodeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x14\n\x12QueryParamsRequest\"~\n\x12QueryNodesResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v1.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x89\x01\n\x1dQueryNodesForProviderResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v1.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"?\n\x11QueryNodeResponse\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x16.sentinel.node.v1.NodeB\x04\xc8\xde\x1f\x00\"E\n\x13QueryParamsResponse\x12.\n\x06params\x18\x01 \x01(\x0b\x32\x18.sentinel.node.v1.ParamsB\x04\xc8\xde\x1f\x00\x32\xa5\x04\n\x0cQueryService\x12p\n\nQueryNodes\x12#.sentinel.node.v1.QueryNodesRequest\x1a$.sentinel.node.v1.QueryNodesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/nodes\x12\xa5\x01\n\x15QueryNodesForProvider\x12..sentinel.node.v1.QueryNodesForProviderRequest\x1a/.sentinel.node.v1.QueryNodesForProviderResponse\"+\x82\xd3\xe4\x93\x02%\x12#/sentinel/providers/{address}/nodes\x12w\n\tQueryNode\x12\".sentinel.node.v1.QueryNodeRequest\x1a#.sentinel.node.v1.QueryNodeResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/nodes/{address}\x12\x81\x01\n\x0bQueryParams\x12$.sentinel.node.v1.QueryParamsRequest\x1a%.sentinel.node.v1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/modules/node/paramsB7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _QUERYNODESRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYNODESFORPROVIDERRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESFORPROVIDERRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYNODERESPONSE.fields_by_name['node']._options = None
  _QUERYNODERESPONSE.fields_by_name['node']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QueryNodes']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodes']._serialized_options = b'\202\323\344\223\002\021\022\017/sentinel/nodes'
  _QUERYSERVICE.methods_by_name['QueryNodesForProvider']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodesForProvider']._serialized_options = b'\202\323\344\223\002%\022#/sentinel/providers/{address}/nodes'
  _QUERYSERVICE.methods_by_name['QueryNode']._options = None
  _QUERYSERVICE.methods_by_name['QueryNode']._serialized_options = b'\202\323\344\223\002\033\022\031/sentinel/nodes/{address}'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\037\022\035/sentinel/modules/node/params'
  _QUERYNODESREQUEST._serialized_start=240
  _QUERYNODESREQUEST._serialized_end=362
  _QUERYNODESFORPROVIDERREQUEST._serialized_start=365
  _QUERYNODESFORPROVIDERREQUEST._serialized_end=515
  _QUERYNODEREQUEST._serialized_start=517
  _QUERYNODEREQUEST._serialized_end=552
  _QUERYPARAMSREQUEST._serialized_start=554
  _QUERYPARAMSREQUEST._serialized_end=574
  _QUERYNODESRESPONSE._serialized_start=576
  _QUERYNODESRESPONSE._serialized_end=702
  _QUERYNODESFORPROVIDERRESPONSE._serialized_start=705
  _QUERYNODESFORPROVIDERRESPONSE._serialized_end=842
  _QUERYNODERESPONSE._serialized_start=844
  _QUERYNODERESPONSE._serialized_end=907
  _QUERYPARAMSRESPONSE._serialized_start=909
  _QUERYPARAMSRESPONSE._serialized_end=978
  _QUERYSERVICE._serialized_start=981
  _QUERYSERVICE._serialized_end=1530
# @@protoc_insertion_point(module_scope)
